@@ -256,6 +256,8 @@ class JsonObject:
 
         return pd.core.series.Series(dict(zip(columns,values)))
 
+    def to_dict(self):
+        return {a: b for a, b in zip(self.get_members(), self.get_values())}
 
 class SortOrder:
     Ascending = 0
